# Changelog

<!--next-version-placeholder-->

## v0.2.0 (2024-05-22)

### Feature

* Publish (postgres) migrations for rbac ([`5d00057`](https://github.com/educationwarehouse/edwh-auth-rbac/commit/5d00057d16e58c87369be0658fa1c62032ea045b))

### Fix

* Improve typing ([`4a1eb6e`](https://github.com/educationwarehouse/edwh-auth-rbac/commit/4a1eb6eec62350729b9e77719dc8426610e2d716))

## v0.1.1 (2024-05-21)

### Fix

* Don't ship venv, ship as edwh_auth_rbac not as src ([`e7a0d4d`](https://github.com/educationwarehouse/edwh-auth-rbac/commit/e7a0d4de6361e941c28c1b3f81cbed1a13f48011))
* Make build actually work ([`57def49`](https://github.com/educationwarehouse/edwh-auth-rbac/commit/57def49f6113f52ed5dffbf32fd01da906d56826))

## v0.1.0 (2024-05-16)

### Feature

* Initial non-nameko version ([`9a292ad`](https://github.com/educationwarehouse/edwh-auth-rbac/commit/9a292ad3de3b7181f2cbcea8c227dbfccc1c4bc4))
